@@ -1,8 +1,9 @@
 package Test::Approvals;
 use strict;
 use warnings FATAL => 'all';
-use version; our $VERSION = qv('v0.0.4_3');
+use version; our $VERSION = qv('v0.0.4_10');
 
+use Data::Dumper;
 use Test::Approvals::Reporters;
 use Test::Approvals::Namers::DefaultNamer;
 use Test::Approvals::Core::FileApprover qw();
@@ -12,8 +13,9 @@ use Test::Builder;
 require Exporter;
 use base qw(Exporter);
 
-our @EXPORT_OK = qw(use_reporter use_reporter_instance verify verify_ok
-  reporter use_name namer);
+our @EXPORT_OK =
+  qw(use_reporter use_reporter_instance verify verify_ok verify_dump
+  reporter use_name use_name_in namer);
 
 my $test = Test::Builder->new();
 my $namer_instance;
@@ -34,6 +36,15 @@ sub use_name {
     return $namer_instance;
 }
 
+sub use_name_in {
+    my ( $test_name, $dir ) = @_;
+    $namer_instance = Test::Approvals::Namers::DefaultNamer->new(
+        name      => $test_name,
+        directory => "$dir"
+    );
+    return $namer_instance;
+}
+
 sub use_reporter_instance {
     $reporter_instance = shift;
     return $reporter_instance;
@@ -57,7 +68,16 @@ sub verify_ok {
     if ( defined $name ) {
         use_name($name);
     }
-    return $test->ok( verify $results, $namer_instance->name );
+    return $test->ok( verify($results), $namer_instance->name );
+}
+
+sub verify_dump {
+    my ( $ref, $name ) = @_;
+    my $dds = $Data::Dumper::Sortkeys;
+    $Data::Dumper::Sortkeys = 1;
+    my $ok = verify_ok Dumper($ref), $name;
+    $Data::Dumper::Sortkeys = $dds;
+    return $ok;
 }
 
 1;
@@ -68,7 +88,7 @@ Test::Approvals - Capture human intelligence in your tests
 
 =head1 VERSION
 
-This documentation refers to Test::Approvals version v0.0.4_3
+This documentation refers to Test::Approvals version v0.0.4_10
 
 =head1 SYNOPSIS
 
@@ -108,6 +128,12 @@ Gets the currently configured Test::Approvals::Reporters:: instance.
 Construct a namer for the specified name, configure it as the current instance, 
 and return the instance.
 
+=head2 use_name_in
+
+    my $namer = use_name_in('My Test Name', 'C:\tests\approvals\');
+
+Like 'use_name', but names will be generated in the specified folder.
+
 =head2 use_reporter
 
     my $reporter = use_reporter('Test::Approvals::Reporters::DiffReporter');
@@ -135,11 +161,7 @@ appropriate.
 
 You can pass anything to verify that Perl can easily stringify in a scalar 
 context.  So, passing an array, a hash, or raw reference to verify is not going 
-to produce useful results.  In these cases, take advantage of Data::Dumper.
-
-    use Data::Dumper;
-    my %person = ( First => 'Fred', Last => 'Flintrock' );
-    ok verify(Dumper( \%person )), 'Fred test';
+to produce useful results.  In these cases, take advantage of verify_dump.
 
 =head2 verify_ok
 
@@ -152,6 +174,18 @@ traditional Test::More experience:
 
     verify_ok 'Hello', 'Hello Test';
 
+=head2 verify_dump
+
+    use_name('Person Test');
+    my %person = ( First => 'Fred', Last => 'Flintrock' );
+    verify_dump \%person;
+
+Like 'verify_ok', but will call Data::Dumper::Dumper on the reference for you.
+Because hash keys are not ordered, and therefore not guaranteed to be stable 
+across runs, this method will enable key sorting inside Data::Dumper using 
+$Data::Dumper::Sortkeys = 1.  Before returning, it restores Sortkeys to it's
+previous value.
+
 =head1 DIAGNOSTICS
 
 None at this time.
@@ -162,11 +196,12 @@ None.
 
 =head1 DEPENDENCIES
 
-=over
+=over 4
 
-Exporter
-Test::Builder
-version
+    Exporter
+    Data::Dumper
+    Test::Builder
+    version
 
 =back
 
@@ -179,6 +214,8 @@ None known.
 Windows-only.  Linux/OSX/other support will be added when time and access to 
 those platforms permit.
 
+Perl 5.14 or greater.
+
 =head1 AUTHOR
 
 Jim Counts - @jamesrcounts
